@@ -31,6 +31,7 @@ class ConfiguredEmailBackend(_ConfiguredEmailBackend):
     def send_messages(self, email_messages):
         fromEmailList = []
         try:
+            # 用 DynamicEmailConfiguration 寄信
             fromEmail = DynamicEmailConfiguration.objects.get().from_email
             for message in email_messages:
                 fromEmailList.append(message.from_email)
@@ -40,9 +41,12 @@ class ConfiguredEmailBackend(_ConfiguredEmailBackend):
             return super(
                 ConfiguredEmailBackend, self).send_messages(email_messages)
         except Exception as e:
+            # 不能用 DynamicEmailConfiguration 寄信，
+            # 因此將 from_email 拿回來試試 SMTP 寄信
             for i, message in enumerate(email_messages, 0):
                 message.from_email = fromEmailList[i]
-            errMsg = ("ERROR: %s\n%s\nUse SmtpEmailBackend to send email" % 
+            errMsg = (("Use dynamic email configuration to send email error: "
+                       "%s\n%s\nUse SmtpEmailBackend to send email") % 
                     (str(e), traceback.format_exc()))
             logger.error(errMsg)
             smtp = SmtpEmailBackend()
@@ -50,17 +54,24 @@ class ConfiguredEmailBackend(_ConfiguredEmailBackend):
                 r = smtp.send_messages(email_messages)
                 return r
             except Exception as e:
-                errMsg = ("ERROR: %s\n%s\nUse SmtpEmailBackend to send email" % 
-                    (str(e), traceback.format_exc()))
+                # 不能用 DynamicEmailConfiguration 寄信，
+                # 而且將 from_email 拿回來也不能用 SMTP 寄信，因此將所有信的
+                # fromEmail 用 settings.DEFAULT_FROM_EMAIL 再用 SMTP 寄一次
+                errMsg = (("Use SMTP to send email error: "
+                           "%s\n%s\nUse SmtpEmailBackend to send email "
+                           "by %s as from Email") % 
+                    (str(e), traceback.format_exc(), 
+                     settings.DEFAULT_FROM_EMAIL))
                 logger.error(errMsg)
                 for message in email_messages:
                     if not message.from_email == settings.DEFAULT_FROM_EMAIL:
-                        message.from_email = fromEmail
+                        message.from_email = settings.DEFAULT_FROM_EMAIL
                 
                 try:                
                     r = smtp.send_messages(email_messages)
                     return r
                 except Exception as e:
+                    # 完全寄不了信
                     errMsg = ("ERROR: %s\n%s\nError send email" % 
                     (str(e), traceback.format_exc()))
                     logger.error(errMsg)
