@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: __init__.py 11799 2019-12-12 09:08:19Z Lavender $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-07-16 18:31:00 +0900 (週一, 16 七月 2018) $
-# $Revision: 11172 $
+# $Date: 2019-12-12 18:08:19 +0900 (週四, 12 十二月 2019) $
+# $Revision: 11799 $
 
 import logging
 import traceback
@@ -27,6 +27,7 @@ from django.conf import settings
 from Iuppiter.Encoding import utf8, _unicode
 from Iuppiter.Json import serializer
 from Iuppiter.Logging import createLogger
+from Iuno.Email import ConfiguredEmailBackend
 
 logger = createLogger(__name__, 'Newsletter.log')
 
@@ -221,8 +222,8 @@ class EmailBackend(BaseEmailBackend):
                 except Exception as e:
                     raise
         except Exception as e:
-            errMsg = ("ERROR: %s\n%s\nUse SmtpEmailBackend to send email" % 
+            errMsg = ("ERROR: %s\n%s\nUse ConfiguredEmailBackendto send email" % 
                       (str(e), traceback.format_exc()))
             logger.error(errMsg)
-            smtp = SmtpEmailBackend()
-            return smtp.send_messages(email_messages)
\ No newline at end of file
+            configureEmailBackend = ConfiguredEmailBackend()
+            return configureEmailBackend.send_messages(email_messages)
\ No newline at end of file
