@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11793 2019-12-11 15:00:31Z Lavender $
+# $Id: __init__.py 11802 2019-12-17 16:04:02Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-12-12 00:00:31 +0900 (週四, 12 十二月 2019) $
-# $Revision: 11793 $
+# $Date: 2019-12-18 01:04:02 +0900 (週三, 18 十二月 2019) $
+# $Revision: 11802 $
 
 import os
 import sys
@@ -505,7 +505,17 @@ def attachSettings(settingsDict, enablePaypal=False):
                     u'商品退貨中': (u'完成退貨', u'測試用訂單'),
                     u'完成退貨': (u'測試用訂單',),
                     u'測試用訂單': (u'等待處理中',),
-                }
+                },
+                'OSCAR_ORDER_STATUS': [
+                    (u'等待處理中', u'等待處理中'),
+                    (u'商品送貨中', u'商品送貨中'),
+                    (u'商品已到貨', u'商品已到貨'),
+                    (u'訂單取消', u'訂單取消'),
+                    (u'完成訂單', u'完成訂單'),
+                    (u'商品退貨中', u'商品退貨中'),
+                    (u'完成退貨', u'完成退貨'),
+                    (u'測試用訂單', u'測試用訂單'),
+                ],
             }
         else:
             ADDING_OSCAR_ORDER_STATUS = {
@@ -514,7 +524,11 @@ def attachSettings(settingsDict, enablePaypal=False):
                 'OSCAR_ORDER_STATUS_PIPELINE': {
                     u'完成訂單': (u'測試用訂單', ),
                     u'測試用訂單': (u'完成訂單',),
-                }
+                },
+                'OSCAR_ORDER_STATUS': [
+                    (u'完成訂單', u'完成訂單'),
+                    (u'測試用訂單', u'測試用訂單'),
+                ],
             }
 
         update(settingsDict, ADDING_OSCAR_ORDER_STATUS)
@@ -535,6 +549,11 @@ def attachSettings(settingsDict, enablePaypal=False):
     }
     update(settingsDict, DEFAULT_CKEDITOR_SETTINGS)
     
+    #=========================================================================
+    
+    #=========================================================================
+    
+    
     
 
 def attachShopURLs(settings, urlpatterns):
