@@ -5,6 +5,7 @@
 from django.db import models
 from django.core import exceptions
 from django.contrib.auth import get_user_model
+from django.conf import settings
 from django.core.validators import MaxValueValidator, MinValueValidator
 from django.utils.translation import gettext_lazy as _
 from solo.models import SingletonModel
@@ -160,6 +161,32 @@ class BonusRecord(models.Model):
         
     createdTime = models.DateTimeField(_("Created Time"), auto_now_add=True)
     
+@property
+def hasReceiveBonus(self):
+    return BonusRecord.objects.filter(order=self).exists()
+    
+@property
+def canReceiveBonus(self):
+    config = BonusSettings.objects.get()
+    
+    # receive
+    if self.shipping_excl_tax:
+        consumption = (
+            int(self.total_excl_tax) - config.consumption - 
+            int(self.shipping_excl_tax))
+    else:
+        consumption = (
+            int(self.total_excl_tax) - config.consumption)
+    
+    receive = 0
+    if consumption >= 0:
+        # config.percent / 100 = X %
+        receive = int(consumption * (config.percent / 100))
+    return receive
+    
+Order.hasReceiveBonus = hasReceiveBonus
+Order.canReceiveBonus = canReceiveBonus
+    
 @property
 def bonusRecords(self):
     return BonusRecord.objects.filter(user=self).order_by('-createdTime')
@@ -182,6 +209,11 @@ class BonusSettings(SingletonModel):
         validators=[MinValueValidator(-1),],
     )
     
+    receiveStatus = models.CharField(
+        choices=settings.OSCAR_ORDER_STATUS, 
+        default=settings.OSCAR_INITIAL_ORDER_STATUS,
+        max_length=50, verbose_name=_("Receive status"))
+    
     includeRange = models.ForeignKey(
         'offer.Range',
         blank=True,
