@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11794 2019-12-11 16:31:08Z Lavender $
+# $Id: views.py 11802 2019-12-17 16:04:02Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-12-12 01:31:08 +0900 (週四, 12 十二月 2019) $
-# $Revision: 11794 $ 
+# $Date: 2019-12-18 01:04:02 +0900 (週三, 18 十二月 2019) $
+# $Revision: 11802 $ 
 
 import json
 import logging
@@ -270,11 +270,12 @@ def placeOrder(self, basket, total,  # noqa (too complex (12))
                     }
                 )
         
-        # bonus        
+        # bonus   
+        config = BonusSettings.objects.get(id=1)
+        
         if user.is_authenticated:
             b, created = Bonus.objects.get_or_create(user=user)
-            config = BonusSettings.objects.get(id=1)
-            
+                
             # receive
             if shipping_charge:
                 consumption = (
@@ -300,18 +301,29 @@ def placeOrder(self, basket, total,  # noqa (too complex (12))
             if bonusVoucher:
                 if len(bonusVoucher.code.split("-")) == 4: 
                     use = int(bonusVoucher.code.split("-")[1])
-                    
-            # update
-            b.quantity = b.quantity + receive - use
-            b.save()
             
-            # record
-            record = BonusRecord.objects.create(
-                user=user,
-                order=order,
-                use=use,
-                receive=receive,
-            )
+            if config.receiveStatus == settings.OSCAR_INITIAL_ORDER_STATUS:
+                # update
+                b.quantity = b.quantity + receive - use
+                b.save()
+                
+                # record
+                record = BonusRecord.objects.create(
+                    user=user,
+                    order=order,
+                    use=use,
+                    receive=receive,
+                )
+                
+                messages.info(
+                    request, _("You earn %d bonus on this order.") % receive)
+            else:
+                messages.info(
+                    request, 
+                    _("When you do complete the order transaction, "
+                      "you will earn %d bonus on this order.") % receive)
+            
+        
             
     return order
     
@@ -375,10 +387,10 @@ from oscar.apps.order.processing import EventHandler
 def sendOrderEmail(order, subjectTemp, htmlTemp, txtTemp):
     try:
         temp = get_template(subjectTemp)
-        ctx = Context({
+        ctx = {
             "order": order,
             "site": Site.objects.get(id=settings.SITE_ID)
-        })
+        }
         subject = temp.render(ctx)
         
         temp = get_template(htmlTemp)
@@ -439,7 +451,7 @@ def handle_order_status_change(self, order, new_status, note_msg=None):
     viewed as a shipping event affecting all lines.
     """
     order.set_status(new_status)
-
+    
     hasSettings = hasattr(settings, 'OSCAR_PROCESSING_SEND_EMAIL_STATUS')
     
     if (hasSettings and 
@@ -463,6 +475,52 @@ def handle_order_status_change(self, order, new_status, note_msg=None):
     
     if note_msg:
         self.create_note(order, note_msg)
+    
+    # bonus
+    config = BonusSettings.objects.get(id=1)
+        
+    if (not order.is_anonymous and 
+        config.receiveStatus == new_status):
+        user = order.user
+        b, created = Bonus.objects.get_or_create(user=user)
+        
+        # receive
+        if order.shipping_excl_tax:
+            consumption = (
+                int(order.total_excl_tax) - config.consumption - 
+                int(order.shipping_excl_tax))
+        else:
+            consumption = (
+                int(order.total_excl_tax) - config.consumption)
+        
+        receive = 0
+        if consumption >= 0:
+            # config.percent / 100 = X %
+            receive = int(consumption * (config.percent / 100))
+            
+        # use
+        use = 0
+        bonusVoucher = None
+        for v in order.basket_discounts.all():
+            if re.match(BONUS_VOUCHER_CODE, v.voucher_code):
+                bonusVoucher = v
+          
+        # len(BONUS-[bouns use]-[bouns discount]-XXXX.split("-")) == 4
+        if bonusVoucher:
+            if len(bonusVoucher.voucher_code.split("-")) == 4: 
+                use = int(bonusVoucher.voucher_code.split("-")[1])
+                
+        # update
+        b.quantity = b.quantity + receive - use
+        b.save()
+        
+        # record
+        record = BonusRecord.objects.create(
+            user=user,
+            order=order,
+            use=use,
+            receive=receive,
+        )
 
 EventHandler.handle_order_status_change = handle_order_status_change
 
@@ -661,6 +719,12 @@ def updateBonus(request, *args, **kwargs):
     user = get_user_model().objects.get(id=pk)
     b, created = Bonus.objects.get_or_create(user=user)
     
+    if not b.quantity + adjust >= 0:
+        messages.error(
+            request, _("Bonus must be greater than 0."))
+        
+        return redirect(reverse("dashboard:user-detail", kwargs={'pk': pk,}))
+        
     # update
     b.quantity += adjust
     b.save()
